@@ -20,13 +20,16 @@ class _SetUserCrudView(BaseCrudView):
 
     def post(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).post(
+            request=request, initkwargs=dict(user=request.resource_owner), *args, **kwargs)
+
+    def post_file(self, request, *args, **kwargs):
+        return super(_SetUserCrudView, self).post_file(
             request=request, files=request._files.dict(), body=request._post.dict(),
             initkwargs=dict(user=request.resource_owner), *args, **kwargs)
 
     def put(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).put(
-            request=request, files=request._files.dict(), body=request._post.dict(),
-            initkwargs=dict(user=request.resource_owner), *args, **kwargs)
+            request=request, initkwargs=dict(user=request.resource_owner), *args, **kwargs)
 
     def delete(self, request, *args, **kwargs):
         return super(_SetUserCrudView, self).delete(
